@@ -10,7 +10,7 @@ sim.gdina <- function( n , q.matrix , delta , link = "identity" ,
     # simulate alpha
 	if ( is.null(alpha) ){
 #		library(MASS)
-		alpha <- 1* ( mvrnorm( n , mu = thresh.alpha , Sigma = cov.alpha ) > 0 )
+		alpha <- 1* ( MASS::mvrnorm( n , mu = thresh.alpha , Sigma = cov.alpha ) > 0 )
 				}
     dat <- matrix( NA , n , I )
     for (ii in 1:I){
